--babel support

local bstr = function(id, value)
	return value
end

local babel, ref_key
local function babel_func()
	if lib.is_ready("babel", "0") then
		babel = lib.get_class("babel", "0")
		ref_key = babel.register("plugins/reskin/lang/", {'en', 'es', 'fr', 'pt'})
		
		bstr = function(id, value)
			return babel.fetch(ref_key, id, value)
		end
	end
end

lib.require({{name='babel', version='0'}}, babel_func)


--reskin v2.3.0

local themes = {}

local select_index = 1
local reskin = {
	CCD1 = true,
	open = nil,
	config = nil,
	smart_config = {
		title = bstr(1, "Reskin UI Theming Framework"),
		cb = function(id, val)
			console_print(id)
			console_print(val)
			if id == 'skin_list' then
				for k, v in ipairs(themes) do
					if v.name == val then
						select_index = k
						break
					end
				end
			elseif val == "_action" then
				gkini.WriteString("Vendetta", "skin", themes[select_index].dir)
				lib.reload()
			end
		end,
		rule = {
			type = "rule",
		},
		spacer = {
			type = "spacer",
		},
		ver_display = {
			type = "text",
			display = bstr(2, "Version ") .. lib.get_latest("reskin"),
			align = "center",
		},
		skin_list = {
			type = "dropdown",
			display = bstr(3, "Select your theme: "),
			default = 1,
		},
		skin_apply = {
			type = "action",
			display = "",
			align = "right",
			[1] = bstr(4, "Apply Skin"),
		},
		skin_warn = {
			type = "text",
			align = "right",
			display = bstr(5, "Some theme elements require a full restart to apply"),
		},
		[1] = 'ver_display',
		[2] = 'rule',
		[3] = 'skin_list',
		[4] = 'skin_apply',
		[5] = 'spacer',
		[6] = 'skin_warn',
	},
	commands = {
		'/reskin',
	},
	manifest = {
		"plugins/reskin/main.lua",
		"plugins/reskin/reskin.lua",
	},
	description = bstr(9, "Reskin is a utility for selecting the theme of Vendetta Online."),
	
	--functions
	register = nil,
	getall = nil,
	getpath = nil,
	getcurrent = nil,
	
	new_lang = nil,
}

reskin.register = function(skin_name, skin_dir)
	if type(skin_name) == "string" and type(skin_dir) == "string" then
		lib.log_error("Reskin: Registering " .. (skin_name))
		lib.log_error("	located at " .. skin_dir)
		local skin = {
			name = skin_name,
			dir = skin_dir,
			cfg = gksys.IsExist(skin_dir .. "config.ini") and "YES" or "NO",
			adv = gksys.IsExist(skin_dir .. "theme.lua") and "YES" or "NO",
		}
		
		if skin.cfg == "YES" then
			lib.log_error("	skin provides a config file!")
		end
		if skin.adv == "YES" then
			lib.log_error("	skin contains an advanced theme generator!")
		end
		
		table.insert(themes, skin)
		table.insert(reskin.smart_config.skin_list, skin.name)
		
		if skin.dir == IMAGE_DIR then
			select_index = #themes
			reskin.smart_config.skin_list.default = #themes
		end
		
		return true
	else
		return false
	end
end

reskin.getall = function()
	local rettable = {}
	for k,v in ipairs(themes) do
		table.insert(rettable, v.name)
	end
	
	return rettable
end

reskin.getcurrent = function()
	for k, v in ipairs(themes) do
		if v.dir == IMAGE_DIR then
			return v.name
		end
	end
	
	return "_unregistered_skin"
end

reskin.get_path = function(skin_name)
	for k, v in ipairs(themes) do
		if v.name == skin_name then
			return v.dir
		end
	end
	
	return "_unregistered_skin"
end

reskin.new_lang = function(path, language_code)
	if babel then
		babel.add_new_lang(ref_key, path, language_code)
	end
end

reskin.open = function()
	local selIndex = 1
	
	local preview_thumb = IMAGE_DIR .. "/preview.png"
	local preview_pane = iup.label {
		title = "",
		image = preview_thumb,
		size = "256x256",
	}
	local function update_preview()
		preview_thumb = themes[selIndex].dir .. "/preview.png"
		
		if themes[selIndex].name == "Default Platinum" then
			preview_thumb = "plugins/Reskin/platinum_preview.png"
		elseif themes[selIndex].name == "Default Blue" then
			preview_thumb = "plugins/Reskin/blue_preview.png"
		end
		
		if not gksys.IsExist(preview_thumb) then
			preview_thumb = "plugins/Reskin/preview.png"
		end
		preview_pane.image = preview_thumb
		iup.Refresh(preview_pane)
	end
	
	update_preview()
	
	local skinlist = iup.list {
		dropdown = "YES",
		action = function(self, name, index, cval)
			if cval == 1 then
				selIndex = index
				update_preview()
			end
		end,
	}
	
	for k, v in ipairs(themes) do
		skinlist[k] = v.name
	end
	
	local newUIToggle = iup.stationtoggle {
		title = "",
		value = "",
		action = function(self)
			if self.value == "ON" then
				gkini.WriteInt("Vendetta", "usenewui", 1)
			else
				gkini.WriteInt("Vendetta", "usenewui", 0)
			end
		end,
	}
	
	if gkini.ReadInt("Vendetta", "usenewui") == 0 then
		newUIToggle.value = "OFF"
	else
		newUIToggle.value = "ON"
	end
	
	local diag = iup.dialog {
		topmost = "YES",
		fullscreen = "YES",
		bgcolor = "0 0 0 200 *",
		iup.hbox {
			iup.fill { },
			iup.vbox {
				iup.fill { },
				iup.label {
					title = "Reskin",
					font = Font.H1,
				},
				iup.frame {
					iup.vbox {
						iup.label {
							title = bstr(6, "Select a skin to load from the list below:"),
						},
						iup.fill {
							size = "%2",
						},
						skinlist,
						iup.fill {
							size = "%1",
						},
						iup.hbox {
							iup.fill { },
							preview_pane,
							iup.fill { },
						},
						iup.hbox {
							iup.fill { },
							iup.label {
								title = bstr(7, "Use 'Angular' UI: "),
							},
							newUIToggle,
						},
						iup.hbox {
							iup.fill { },
							iup.stationbutton {
								title = bstr(4, "Load selected skin"),
								action = function()
									gkini.WriteString("Vendetta", "skin", themes[selIndex].dir)
									ReloadInterface()
								end,
							},
							iup.stationbutton {
								title = bstr(8, "Cancel"),
								action = function(self)
									HideDialog(iup.GetDialog(self))
									iup.Destroy(iup.GetDialog(self))
								end,
							},
						},
					},
				},
				iup.fill { },
			},
			iup.fill { },
		},
	}
	diag:map()
	diag:show()
end

reskin.config = reskin.open

reskin.register("Default Platinum", "skins/platinum/")
reskin.register("Default Blue", "images/station/")

lib.set_class("reskin", "0", reskin)